@@ -3,15 +3,25 @@ import cv2
 import base64
 import numpy as np
 
+from ndu_gate_camera.utility import geometry_helper
+from ndu_gate_camera.utility.ndu_utility import NDUUtility
+
+
+def image_h_w(image):
+    # h, w = image.shape[:2]
+    return image.shape[:2]
+
 
 # Boyut değişikliğine en uygun interpolation yöntemi ile resize eder.
 def resize_best_quality(image, size):
+    if image.shape[0] == size[0] and image.shape[1] == size[1]:
+        return image.copy()
     size0 = max(image.shape[0], image.shape[1])
     size1 = max(size[0], size[1])
-    if size0 == size1:
-        return image.copy()
-    elif size0 > size1:
-        return cv2.resize(image, size, interpolation=cv2.INTER_LANCZOS4)
+    if size0 > size1:
+        # if size0 > 2 * size1:
+        #     image = cv2.pyrDown(image)
+        return cv2.resize(image, size, interpolation=cv2.INTER_AREA)
     else:
         return cv2.resize(image, size, interpolation=cv2.INTER_CUBIC)
 
@@ -69,7 +79,7 @@ def resize(image, width=None, height=None, interpolation=None):
 
 
 # total_pixel_count sonucun width * height değeridir.
-# int yuvarlaması yüzünden sonuç w*h değer, tam total_pixel_count olmayabilir.
+# int yuvarlama yüzünden sonuç w*h değer, tam total_pixel_count olmayabilir.
 def resize_total_pixel_count(image, total_pixel_count):
     h, w = image.shape[:2]
     ratio = w / float(h)
@@ -100,8 +110,7 @@ def fill_polyline_transparent(image, pnts, color, opacity, thickness=-1):
     cv2.copyTo(res, None, image)
 
 
-def select_areas(frame, window_name, color=(0, 0, 255), opacity=0.3, thickness=4, max_count=None, next_area_key="n",
-                 finish_key="s"):
+def select_areas(frame, window_name, color=(0, 0, 255), opacity=0.3, thickness=4, max_count=None, next_area_key="n", finish_key="s", return_tuples=True, max_point_count=None):
     try:
         areas = []
         area = []
@@ -143,9 +152,14 @@ def select_areas(frame, window_name, color=(0, 0, 255), opacity=0.3, thickness=4
                 break
             elif k & 0xFF == ord(next_area_key):
                 new_area = True
+            elif max_point_count is not None and len(area) == max_point_count:
+                new_area = True
 
         if len(area) > 2:
             areas.append(area)
+        if not return_tuples:
+            for i in range(len(areas)):
+                areas[i] = np.array(areas[i], np.int32)
         return areas
     finally:
         cv2.destroyWindow(window_name)
@@ -215,9 +229,11 @@ def select_points(frame, window_name, color=(0, 255, 255), radius=8, thickness=4
         cv2.destroyWindow(window_name)
 
 
-def put_text(img, text_, center, color=None, font_scale=0.5, thickness=1, back_color=None):
+def put_text(img, text_, center, color=None, font_scale=0.5, thickness=1, back_color=None, replace_tur_chars=True):
+    if replace_tur_chars:
+        text_ = NDUUtility.debug_replace_tur_chars(text_)
     if back_color is None:
-        back_color = [0, 0, 0]
+        back_color = [1, 1, 1]
     if color is None:
         color = [255, 255, 255]
     y = center[1]
@@ -294,3 +310,76 @@ def convert_lines_tuple2list(lines):
             line1.append(list(c))
         res.append(line1)
     return res
+
+
+def crop(frame, rect):
+    y1 = max(int(rect[0]), 0)
+    x1 = max(int(rect[1]), 0)
+    y2 = max(int(rect[2]), 0)
+    x2 = max(int(rect[3]), 0)
+    return frame[y1:y2, x1:x2]
+
+
+def change_brightness(img, value):
+    hsv = cv2.cvtColor(img, cv2.COLOR_BGR2HSV)
+    h, s, v = cv2.split(hsv)
+
+    if value > 0:
+        lim = 255 - value
+        v[v > lim] = 255
+        v[v <= lim] += value
+    else:
+        lim = 0 - value
+        v[v < lim] = 0
+        v[v >= lim] -= abs(value)
+
+    final_hsv = cv2.merge((h, s, v))
+    img = cv2.cvtColor(final_hsv, cv2.COLOR_HSV2BGR)
+    return img
+
+
+def get_mask(shape, areas):
+    h, w = shape[:2]
+    mask = np.zeros((h, w), np.uint8)
+    contours = []
+    for area in areas:
+        contours.append(np.array(area, np.int32))
+    cv2.drawContours(mask, contours, -1, 255, -1)
+    return mask
+
+
+def apply_mask(image, mask):
+    return cv2.bitwise_and(image, image, mask=mask)
+
+
+def draw_rect(image, rect, color=None):
+    if color is None:
+        color = [255, 255, 255]
+    c = np.array(rect[:4], dtype=np.int32)
+    c1, c2 = geometry_helper.get_rect_pnts(c)
+    cv2.rectangle(image, c1, c2, color=[1, 1, 1], thickness=3)
+    cv2.rectangle(image, c1, c2, color=color, thickness=2)
+
+
+def equalize_hist_bgr(img):
+    img_yuv = cv2.cvtColor(img, cv2.COLOR_BGR2YUV)
+    img_yuv[:, :, 0] = cv2.equalizeHist(img_yuv[:, :, 0])
+    return cv2.cvtColor(img_yuv, cv2.COLOR_YUV2BGR)
+
+    # img[:, :, 0] = cv2.equalizeHist(img[:, :, 0])
+    # img[:, :, 1] = cv2.equalizeHist(img[:, :, 1])
+    # img[:, :, 2] = cv2.equalizeHist(img[:, :, 2])
+    # return img
+
+
+def adaptive_equalize_hist_bgr(img):
+    clahe = cv2.createCLAHE(clipLimit=2.0, tileGridSize=(8, 8))
+    img_yuv = cv2.cvtColor(img, cv2.COLOR_BGR2YUV)
+    img_yuv[:, :, 0] = clahe.apply(img_yuv[:, :, 0])
+    return cv2.cvtColor(img_yuv, cv2.COLOR_YUV2BGR)
+
+    # clahe = cv2.createCLAHE(clipLimit=2.0, tileGridSize=(8, 8))
+    # img[:, :, 0] = clahe.apply(img[:, :, 0])
+    # img[:, :, 1] = clahe.apply(img[:, :, 1])
+    # img[:, :, 2] = clahe.apply(img[:, :, 2])
+    # return img
